@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 '''preggy file assertions.  For use with `expect()` (see `preggy.core`).
 
@@ -15,20 +14,28 @@ a "file" in your tests.
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2013 Bernardo Heynemann heynemann@gmail.com
 
-from os.path import isfile
+try:
+    import six
+except ImportError:
+    print("Ignoring six. Probably setup.py installing package.")
 
 try:
     import io
 except ImportError:
+    ## FIXME: explain using "pass" here
     pass
 
+from os.path import isfile
 import types
 
 from preggy import assertion
 
 
 # Helpers
-_isfile = lambda topic: isfile(topic)
+#-------------------------------------------------------------------------------------------------
+
+_is_file = lambda topic: isfile(topic)
+_is_string = lambda topic: isinstance(topic, (six.string_types, six.text_type))
 
 
 def _is_file_obj(topic):
@@ -37,16 +44,7 @@ def _is_file_obj(topic):
     except AttributeError:
         return isinstance(topic, io.IOBase)
 
-
-def _is_string(topic):
-    try:
-        if isinstance(topic, basestring):
-            return True
-    except NameError:
-        if isinstance(topic, str):
-            return True
-
-    return False
+#-------------------------------------------------------------------------------------------------
 
 
 @assertion
@@ -60,32 +58,32 @@ def to_be_a_file(topic):
     built-in `file` type.
 
     '''
-    VAE = AssertionError("Expected topic({0}) to be a file", topic)
+    AE = AssertionError("Expected topic({0}) to be a file", topic)
 
     if _is_string(topic):
-        if not _isfile(topic):
-            raise VAE
+        if not _is_file(topic):
+            raise AE
     else:
         if not _is_file_obj(topic):
-            raise VAE
+            raise AE
 
 
 @assertion
 def not_to_be_a_file(topic):
     '''Asserts that `topic` is NOT a file.
 
-     If `topic` is a string, this asserts whether `os.path.isfile()`
-     returns `False`.
+    If `topic` is a string, this asserts whether `os.path.isfile()`
+    returns `False`.
 
     Otherwise, this asserts whether `topic` is not an instance of the
     built-in `file` type.
 
     '''
-    VAE = AssertionError("Expected topic({0}) not to be a file", topic)
+    AE = AssertionError("Expected topic({0}) not to be a file", topic)
 
     if _is_string(topic):
-        if _isfile(topic):
-            raise VAE
+        if _is_file(topic):
+            raise AE
     else:
         if _is_file_obj(topic):
-            raise VAE
+            raise AE
