@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 '''preggy regular expression assertions.  For use with `expect()` (see `preggy.core`).
 '''
@@ -17,19 +16,13 @@ from preggy import assertion
 
 @assertion
 def to_match(topic, expected):
-    '''Asserts that `topic` matches the regular expression
-    `expected`.
-
-    '''
+    '''Asserts that `topic` matches the regular expression `expected`.'''
     if not re.match(expected, topic):
         raise AssertionError('Expected topic({0}) to match the regular expression {1}', topic, expected)
 
 
 @assertion
 def not_to_match(topic, expected):
-    '''Asserts that `topic` DOES NOT match the regular expression
-    `expected`.
-
-    '''
+    '''Asserts that `topic` DOES NOT match the regular expression `expected`.'''
     if re.match(expected, topic):
         raise AssertionError('Expected topic({0}) not to match the regular expression {1}', topic, expected)
